# Chatbot SPARQL service

Middleware for chatbots trying to retrieve data from a SPARQL endpoint. 
A suitable SPARQL query is constructed and sent to the server once a request with intent, search terms, and entities is received.
A list of datasets is then returned in response.


## Setup

1. Install all of the following software
        
* Java JDK >= 1.8
* Git >= 2.17
  
2. Clone the directory and enter it
            
3. Adjust the following environment variables to your liking:
   
| Key | Description | Default |
| :--- | :--- | :--- |
| PORT | Port this service will run on. | 8080 |
| SPARQL_URL | SPARQL endpoint server address. | https://www.europeandataportal.eu/sparql |
| PAGE_SIZE | Number of datasets to return. Can be overwritten in request. | 3 |
| ENABLE_BIF | Explicitly set Virtuoso's _[bif:contains](http://docs.openlinksw.com/virtuoso/rdfsparqlrulefulltext/)_ to be used for string matching. If not set, the configured SPARQL endpoint will be tested for support. Expects either _true_ or _false_. |  |
| CHATSCRIPT_HOST & CHATSCRIPT_PORT | Port on which server instance of ChatScript is running. Required for testing. Not setting this variable will skip the test. | 8081 |

        
## Run

### Production

Build the project by using the provided Maven wrapper. This ensures everyone this software is provided to can use the exact same version of the maven build tool.
The generated _fat-jar_ can then be found in the `target` directory.

* Linux
    
        ./mvnw clean package
        java -jar target/chatbot-sparql-service-1.0-fat.jar

* Windows

        mvnw.cmd clean package
        java -jar target/chatbot-sparql-service-1.0-fat.jar
      
* Docker

    1. Start your docker daemon 
    2. Build the application as described in _Windows_ or _Linux_
    3. Build the image: `docker build -t edp/chatbot-sparql-service .`
    4. Run the image, adjusting the port number if changed: `docker run -i -p 8080:8080 edp/chatbot-sparql-service`
    5. Configuration can be changed without rebuilding the image by overriding variables: `-e PORT=8081`

### Development

For use in development two scripts are provided in the project's root folder. These enable hot deployment (dynamic recompiling when changes are made to the source code).
Linux users should run the `redeploy.sh` and Windows users the `redeploy.bat` file.

## API

A formal OpenAPI 3 specification can be found in the `src/main/resources/webroot/openapi.yaml` file.
A visually more appealing version is available at `{url}:{port}` once the application has been started.