package de.fhg.fokus.edp.chatbot_sparql_service;

import org.apache.jena.rdf.model.Model;
import org.apache.jena.rdf.model.ModelFactory;
import org.apache.jena.rdf.model.Resource;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import java.io.IOException;
import java.io.InputStream;
import java.util.Optional;

import static org.junit.jupiter.api.Assertions.*;

class FormatParserTest {

    private static final String expectedMediaType = "http://publications.europa.eu/resource/authority/file-type/CSV";

    private Model fileTypeModel;

    @BeforeEach
    void setUp() {
        if (fileTypeModel == null) {
            fileTypeModel = ModelFactory.createDefaultModel();

            try (InputStream is = getClass().getClassLoader().getResourceAsStream("vocabularies/fileTypes.rdf")) {
                if (is != null) {
                    fileTypeModel.read(is, null, "RDF/XML");
                } else {
                    throw new IOException("File type InputStream is null");
                }
            } catch (IOException e) {
                fail(e);
            }
        }
    }

    @Test
    void testFileType() {
        Optional<Resource> mediaType = SparqlUtils.getMediaTypeByFormatName(fileTypeModel, "CSV");

        assertTrue(mediaType.isPresent());
        assertEquals(expectedMediaType, mediaType.get().getURI());
    }

    @Test
    void testFileTypeLowerCase() {
        Optional<Resource> mediaType = SparqlUtils.getMediaTypeByFormatName(fileTypeModel, "csv");

        assertTrue(mediaType.isPresent());
        assertEquals(expectedMediaType, mediaType.get().getURI());
    }

    @Test
    void testInvalidFileType() {
        assertFalse(SparqlUtils.getMediaTypeByFormatName(fileTypeModel, "invalid_format").isPresent());
    }
}
