package de.fhg.fokus.edp.chatbot_sparql_service;

import org.apache.jena.rdf.model.Model;
import org.apache.jena.rdf.model.ModelFactory;
import org.apache.jena.rdf.model.Resource;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import java.io.IOException;
import java.io.InputStream;
import java.util.Optional;

import static org.junit.jupiter.api.Assertions.*;


class LanguageParserTest {

    private static final String expectedLanguage = "http://publications.europa.eu/resource/authority/language/ENG";

    private Model languageModel;

    @BeforeEach
    void setUp() {
        if (languageModel == null) {
            languageModel = ModelFactory.createDefaultModel();

            try (InputStream is = getClass().getClassLoader().getResourceAsStream("vocabularies/languages.rdf")) {
                if (is != null) {
                    languageModel.read(is, null, "RDF/XML");
                } else {
                    throw new IOException("Language file InputStream is null");
                }
            } catch (IOException e) {
                fail(e);
            }
        }
    }

    @Test
    void testAuthorityCode() {
        checkLanguage("eng");
    }

    @Test
    void testAuthorityCodeCapitalized() {
        checkLanguage("ENG");
    }

    @Test
    void testLegacyCode() {
        checkLanguage("en");
    }

    @Test
    void testLegacyCodeCapitalized() {
        checkLanguage("EN");
    }

    @Test
    void testFullName() {
        checkLanguage("english");
    }

    @Test
    void testFullNameCapitalized() {
        checkLanguage("English");
    }

    @Test
    void testInvalidLanguage() {
        assertFalse(SparqlUtils.getLinguisticSystemByLanguageName(languageModel, "invalid_language").isPresent());
    }

    private void checkLanguage(String testLanguage) {
        Optional<Resource> language = SparqlUtils.getLinguisticSystemByLanguageName(languageModel, testLanguage);

        assertTrue(language.isPresent());
        assertEquals(expectedLanguage, language.get().getURI());
    }
}
