package de.fhg.fokus.edp.chatbot_sparql_service.bot;

import org.junit.jupiter.api.extension.ConditionEvaluationResult;
import org.junit.jupiter.api.extension.ExecutionCondition;
import org.junit.jupiter.api.extension.ExtensionContext;

import java.util.Arrays;
import java.util.Optional;

import static org.junit.platform.commons.util.AnnotationUtils.findAnnotation;

public class AssumeEnvVariableCondition implements ExecutionCondition {

    @Override
    public ConditionEvaluationResult evaluateExecutionCondition(ExtensionContext context) {
        Optional<AssumeEnvVariable> annotation = findAnnotation(context.getElement(), AssumeEnvVariable.class);
        return annotation.map(assumeEnvVariable ->
            Arrays.stream(assumeEnvVariable.envVariables()).allMatch(variable -> {
                String value = System.getenv(variable);

                if (value == null)
                    return false;

                if (variable.toLowerCase().contains("port")) {
                    try {
                        Integer.valueOf(value);
                    } catch (NumberFormatException e) {
                        return false;
                    }
                }

                return true;
            })

                ? ConditionEvaluationResult.enabled("All environment variables set, commencing test ...")
                : ConditionEvaluationResult.disabled("Some environment variables not set, skipping test ...")

        ).orElseGet(() -> ConditionEvaluationResult.enabled("No AssumeEnvVariable annotation found, commencing test ..."));
    }
}
